"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseGoVendorConfig = void 0;
const errors_1 = require("../errors");
function parseGovendorJsonContents(jsonStr) {
    try {
        const gvJson = JSON.parse(jsonStr);
        const goProjectConfig = {
            ignoredPkgs: [],
            lockedVersions: {},
            packageName: gvJson.rootPath,
        };
        const packages = gvJson.package || gvJson.Package;
        if (packages) {
            packages.forEach((pkg) => {
                const revision = pkg.revision || pkg.Revision || pkg.version || pkg.Version;
                const version = pkg.versionExact || '#' + revision;
                const dep = {
                    name: pkg.path,
                    version,
                };
                goProjectConfig.lockedVersions[dep.name] = dep;
            });
        }
        const ignores = gvJson.ignore || '';
        ignores
            .split(/\s/)
            .filter((s) => {
            // otherwise it's a build-tag rather than a pacakge
            return s.indexOf('/') !== -1;
        })
            .forEach((pkgName) => {
            pkgName = pkgName.replace(/\/+$/, ''); // remove trailing /
            goProjectConfig.ignoredPkgs.push(pkgName);
            goProjectConfig.ignoredPkgs.push(pkgName + '/*');
        });
        return goProjectConfig;
    }
    catch (e) {
        throw new errors_1.InvalidUserInputError('vendor.json parsing failed with error ' + e.message);
    }
}
function parseGoVendorConfig(manifestFileContents) {
    if (!manifestFileContents) {
        throw new errors_1.InvalidUserInputError('vendor.json file contents are empty');
    }
    return parseGovendorJsonContents(manifestFileContents);
}
exports.parseGoVendorConfig = parseGoVendorConfig;
//# sourceMappingURL=govendor-parser.js.map